package com.example.fuse.payment_service;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.InputStream;

import javax.activation.DataHandler;

import com.example.fuse.payment_service.types.Response;
import com.example.fuse.payment_service.types.Transfer;
import com.example.fuse.payment_service.types.Document;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.InitializingBean;
import org.apache.servicemix.util.FileUtil;

import java.io.File;
import java.io.FileOutputStream;
import java.io.FileNotFoundException;
import java.io.IOException;

public class PaymentImpl implements Payment, InitializingBean {
    private static final Log LOG = LogFactory.getLog(PaymentImpl.class);

    public Response transferFunds(Transfer payload) {
        Response response = new Response();

        LOG.info("Transfered amount " + payload.getAmount()
                + " from " + payload.getFrom()
                + " to " + payload.getTo());

        response.setReply("OK");

        return response;
    }

    public boolean storeDocument(Document record) {
    	InputStream in = null;
    	FileOutputStream out = null;
    	DataHandler handler = record.getImageData();
        LOG.info("Storing document " + record.getName() + " with content type: " + handler.getDataSource().getContentType());
        try {
			in = handler.getInputStream();
			out = new FileOutputStream(new File("c:/Temp/" + record.getName() + "." + "png"));
			FileUtil.copyInputStream(in, out);
	        return true;
        } catch (Exception e) {
            LOG.error("Exception in com.example.fuse.payment_service.PaymentImpl: " + e.getMessage());
            return false;
        } finally {
        	if (out != null) {
        		try {
        			out.close();
        		} catch (Exception e) {
        			
        		}
        		out = null;
        	}
        	if (in != null) {
        		try {
        			in.close();
        		} catch (Exception e) {
        			
        		}
        		in = null;
        	}
        }
    }

    public void afterPropertiesSet() throws Exception {
        LOG.info("PaymentImpl afterPropertiesSet");
    }
}
